# yaqd-lightcon

[![PyPI version](https://badge.fury.io/py/yaqd-lightcon.svg)](https://badge.fury.io/py/yaqd-lightcon)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqd-lightcon)](https://anaconda.org/conda-forge/yaqd-lightcon)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.0M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://gitlab.com/yaq/yaqd-lightcon/-/blob/master/CHANGELOG.md)

yaq daemons for Light Conversion hardware

This package contains the following daemon(s):
- [lightcon-topas4-motor](https://yaq.fyi/daemons/lightcon-topas4-motor/)
- [lightcon-topas4-shutter](https://yaq.fyi/daemons/lightcon-topas4-shutter/)
